@@ -40,3 +40,6 @@ def delete_group(state: State, group: str):
 
     entitlements_client = EntitlementsClient(connection)
     entitlements_client.delete_group(group)
+
+    if state.is_user_friendly_mode():
+        print("1 group deleted")
