@@ -10,7 +10,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-"""Legal info command"""
+"""Legal service info command"""
 
 import click
 
