@@ -17,6 +17,7 @@ import click
 from osducli.click_cli import CustomClickCommand, State, command_with_output
 from osducli.cliclient import handle_cli_exceptions
 from osducli.commands.schema._const import (
+    SCHEMA_DOCUMENTATION,
     SCHEMA_SERVICE_NAME,
     SCHEMA_STATUS_PATH,
     SCHEMA_SWAGGER_PATH,
@@ -32,5 +33,10 @@ from osducli.util.service_info import info
 def _click_command(state: State) -> dict:
     """Information about the service"""
     return info(
-        state, SCHEMA_SERVICE_NAME, CONFIG_SCHEMA_URL, SCHEMA_STATUS_PATH, SCHEMA_SWAGGER_PATH
+        state,
+        SCHEMA_SERVICE_NAME,
+        CONFIG_SCHEMA_URL,
+        SCHEMA_STATUS_PATH,
+        SCHEMA_SWAGGER_PATH,
+        SCHEMA_DOCUMENTATION,
     )
