@@ -22,14 +22,26 @@ from osducli.cliclient import CliOsduClient, handle_cli_exceptions
 # click entry point
 @click.command(cls=CustomClickCommand)
 @click.argument("id")
+@click.option(
+    "-l",
+    "--limit",
+    "limit",
+    default=10,
+    show_default=True,
+    help="maximum number of records to return.",
+)
 @handle_cli_exceptions
 @command_with_output("results[*]")
-def _click_command(state: State, id: str):  # noqa:W1 pylint: disable=invalid-name,redefined-builtin
+def _click_command(
+    state: State, id: str, limit: int
+):  # noqa:W1 pylint: disable=invalid-name,redefined-builtin
     """Search for the specified id"""
-    return query(state, id)
+    return query(state, id, limit)
 
 
-def query(state: State, id: str):  # TO FIX later pylint: disable=invalid-name,redefined-builtin
+def query(
+    state: State, id: str, limit: int
+):  # TO FIX later pylint: disable=invalid-name,redefined-builtin
     """Search for the specified id
 
     Args:
@@ -38,6 +50,6 @@ def query(state: State, id: str):  # TO FIX later pylint: disable=invalid-name,r
     connection = CliOsduClient(state.config)
 
     search_client = SearchClient(connection)
-    json_response = search_client.query_by_id(id)
+    json_response = search_client.query_by_id(id, limit)
 
     return json_response
