@@ -37,4 +37,7 @@ def delete(state: State, id: str):  # pylint: disable=invalid-name,redefined-bui
     """
     connection = CliOsduClient(state.config)
     url = "records/" + id
-    connection.cli_delete(CONFIG_STORAGE_URL, url)
+    connection.cli_delete(CONFIG_STORAGE_URL, url, [200, 204])
+
+    if state.is_user_friendly_mode():
+        print("1 record deleted")
